@@ -5,7 +5,8 @@ import time
 import board
 import adafruit_hts221
 
-i2c = board.I2C()
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 hts = adafruit_hts221.HTS221(i2c)
 
 data_rate = adafruit_hts221.Rate.label[hts.data_rate]
